@@ -7,11 +7,11 @@
 
 #include "kjobtest.h"
 
+#include <QList>
 #include <QMetaEnum>
 #include <QSignalSpy>
 #include <QTest>
 #include <QTimer>
-#include <QVector>
 
 #include <string>
 
@@ -72,11 +72,6 @@ void KJobTest::testProgressTracking()
     qRegisterMetaType<KJob *>("KJob*");
     qRegisterMetaType<qulonglong>("qulonglong");
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QSignalSpy processed_spy(job, qOverload<KJob *, KJob::Unit, qulonglong>(&KJob::processedAmount));
-    QSignalSpy total_spy(job, qOverload<KJob *, KJob::Unit, qulonglong>(&KJob::totalAmount));
-    QSignalSpy percent_spy(job, qOverload<KJob *, ulong>(&KJob::percent));
-#endif
     QSignalSpy processedChanged_spy(job, &KJob::processedAmountChanged);
     QSignalSpy totalChanged_spy(job, &KJob::totalAmountChanged);
     QSignalSpy percentChanged_spy(job, &KJob::percentChanged);
@@ -87,13 +82,6 @@ void KJobTest::testProgressTracking()
      */
     testJob->setProcessedSize(1);
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(processed_spy.size(), 1);
-    QCOMPARE(processed_spy.at(0).at(0).value<KJob *>(), static_cast<KJob *>(job));
-    QCOMPARE(processed_spy.at(0).at(2).value<qulonglong>(), qulonglong(1));
-    QCOMPARE(total_spy.size(), 0);
-    QCOMPARE(percent_spy.size(), 0);
-#endif
     QCOMPARE(processedChanged_spy.size(), 1);
     QCOMPARE(processedChanged_spy.at(0).at(0).value<KJob *>(), static_cast<KJob *>(job));
     QCOMPARE(processedChanged_spy.at(0).at(2).value<qulonglong>(), qulonglong(1));
@@ -105,15 +93,6 @@ void KJobTest::testProgressTracking()
      */
     testJob->setTotalSize(10);
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(processed_spy.size(), 1);
-    QCOMPARE(total_spy.size(), 1);
-    QCOMPARE(total_spy.at(0).at(0).value<KJob *>(), job);
-    QCOMPARE(total_spy.at(0).at(2).value<qulonglong>(), qulonglong(10));
-    QCOMPARE(percent_spy.size(), 1);
-    QCOMPARE(percent_spy.at(0).at(0).value<KJob *>(), job);
-    QCOMPARE(percent_spy.at(0).at(1).value<unsigned long>(), static_cast<unsigned long>(10));
-#endif
     QCOMPARE(processedChanged_spy.size(), 1);
     QCOMPARE(totalChanged_spy.size(), 1);
     QCOMPARE(totalChanged_spy.at(0).at(0).value<KJob *>(), job);
@@ -127,13 +106,6 @@ void KJobTest::testProgressTracking()
      */
     testJob->setPercent(15);
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(processed_spy.size(), 1);
-    QCOMPARE(total_spy.size(), 1);
-    QCOMPARE(percent_spy.size(), 2);
-    QCOMPARE(percent_spy.at(1).at(0).value<KJob *>(), job);
-    QCOMPARE(percent_spy.at(1).at(1).value<unsigned long>(), static_cast<unsigned long>(15));
-#endif
     QCOMPARE(processedChanged_spy.size(), 1);
     QCOMPARE(totalChanged_spy.size(), 1);
     QCOMPARE(percentChanged_spy.size(), 2);
@@ -145,15 +117,6 @@ void KJobTest::testProgressTracking()
      */
     testJob->setProcessedSize(3);
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(processed_spy.size(), 2);
-    QCOMPARE(processed_spy.at(1).at(0).value<KJob *>(), job);
-    QCOMPARE(processed_spy.at(1).at(2).value<qulonglong>(), qulonglong(3));
-    QCOMPARE(total_spy.size(), 1);
-    QCOMPARE(percent_spy.size(), 3);
-    QCOMPARE(percent_spy.at(2).at(0).value<KJob *>(), job);
-    QCOMPARE(percent_spy.at(2).at(1).value<unsigned long>(), static_cast<unsigned long>(30));
-#endif
     QCOMPARE(processedChanged_spy.size(), 2);
     QCOMPARE(processedChanged_spy.at(1).at(0).value<KJob *>(), job);
     QCOMPARE(processedChanged_spy.at(1).at(2).value<qulonglong>(), qulonglong(3));
@@ -166,11 +129,6 @@ void KJobTest::testProgressTracking()
      * No signal is emitted.
      */
     testJob->setTotalSize(10);
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(processed_spy.size(), 2);
-    QCOMPARE(total_spy.size(), 1);
-    QCOMPARE(percent_spy.size(), 3);
-#endif
     QCOMPARE(processedChanged_spy.size(), 2);
     QCOMPARE(totalChanged_spy.size(), 1);
     QCOMPARE(percentChanged_spy.size(), 3);
@@ -180,15 +138,6 @@ void KJobTest::testProgressTracking()
      */
     testJob->setProcessedSize(0);
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(processed_spy.size(), 3);
-    QCOMPARE(processed_spy.at(2).at(0).value<KJob *>(), job);
-    QCOMPARE(processed_spy.at(2).at(2).value<qulonglong>(), qulonglong(0));
-    QCOMPARE(total_spy.size(), 1);
-    QCOMPARE(percent_spy.size(), 4);
-    QCOMPARE(percent_spy.at(3).at(0).value<KJob *>(), job);
-    QCOMPARE(percent_spy.at(3).at(1).value<unsigned long>(), static_cast<unsigned long>(0));
-#endif
     QCOMPARE(processedChanged_spy.size(), 3);
     QCOMPARE(processedChanged_spy.at(2).at(0).value<KJob *>(), job);
     QCOMPARE(processedChanged_spy.at(2).at(2).value<qulonglong>(), qulonglong(0));
@@ -205,15 +154,6 @@ void KJobTest::testProgressTracking()
      */
     testJob->setProcessedSize(15);
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(processed_spy.size(), 4);
-    QCOMPARE(processed_spy.at(3).at(0).value<KJob *>(), job);
-    QCOMPARE(processed_spy.at(3).at(2).value<qulonglong>(), qulonglong(15));
-    QCOMPARE(total_spy.size(), 1);
-    QCOMPARE(percent_spy.size(), 5);
-    QCOMPARE(percent_spy.at(4).at(0).value<KJob *>(), job);
-    QCOMPARE(percent_spy.at(4).at(1).value<unsigned long>(), static_cast<unsigned long>(150));
-#endif
     QCOMPARE(processedChanged_spy.size(), 4);
     QCOMPARE(processedChanged_spy.at(3).at(0).value<KJob *>(), job);
     QCOMPARE(processedChanged_spy.at(3).at(2).value<qulonglong>(), qulonglong(15));
@@ -222,11 +162,6 @@ void KJobTest::testProgressTracking()
     QCOMPARE(percentChanged_spy.at(4).at(0).value<KJob *>(), job);
     QCOMPARE(percentChanged_spy.at(4).at(1).value<unsigned long>(), static_cast<unsigned long>(150));
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    processed_spy.clear();
-    total_spy.clear();
-    percent_spy.clear();
-#endif
     processedChanged_spy.clear();
     totalChanged_spy.clear();
     percentChanged_spy.clear();
@@ -236,24 +171,13 @@ void KJobTest::testProgressTracking()
      */
     testJob->setProgressUnit(KJob::Files);
     testJob->setProcessedSize(16);
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(percent_spy.size(), 0); // no impact on percent
-#endif
     QCOMPARE(percentChanged_spy.size(), 0);
 
     testJob->setTotalFiles(5);
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(percent_spy.size(), 1);
-    QCOMPARE(percent_spy.at(0).at(1).value<unsigned long>(), static_cast<unsigned long>(0));
-#endif
     QCOMPARE(percentChanged_spy.size(), 1);
     QCOMPARE(percentChanged_spy.at(0).at(1).value<unsigned long>(), static_cast<unsigned long>(0));
 
     testJob->setProcessedFiles(2);
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 80)
-    QCOMPARE(percent_spy.size(), 2);
-    QCOMPARE(percent_spy.at(1).at(1).value<unsigned long>(), static_cast<unsigned long>(40));
-#endif
     QCOMPARE(percentChanged_spy.size(), 2);
     QCOMPARE(percentChanged_spy.at(1).at(1).value<unsigned long>(), static_cast<unsigned long>(40));
 
@@ -370,7 +294,7 @@ void KJobTest::testDestroy()
 void KJobTest::testEmitAtMostOnce_data()
 {
     QTest::addColumn<bool>("autoDelete");
-    QTest::addColumn<QVector<Action>>("actions");
+    QTest::addColumn<QList<Action>>("actions");
 
     const auto actionName = [](Action action) {
         return QMetaEnum::fromType<Action>().valueToKey(static_cast<int>(action));
@@ -380,7 +304,7 @@ void KJobTest::testEmitAtMostOnce_data()
         for (Action a : {Action::Start, Action::KillQuietly, Action::KillVerbosely}) {
             for (Action b : {Action::Start, Action::KillQuietly, Action::KillVerbosely}) {
                 const auto dataTag = std::string{actionName(a)} + '-' + actionName(b) + (autoDelete ? "-autoDelete" : "");
-                QTest::newRow(dataTag.c_str()) << autoDelete << QVector<Action>{a, b};
+                QTest::newRow(dataTag.c_str()) << autoDelete << QList<Action>{a, b};
             }
         }
     }
@@ -394,7 +318,7 @@ void KJobTest::testEmitAtMostOnce()
     QFETCH(bool, autoDelete);
     job->setAutoDelete(autoDelete);
 
-    QFETCH(QVector<Action>, actions);
+    QFETCH(QList<Action>, actions);
     for (auto action : actions) {
         switch (action) {
         case Action::Start:
@@ -494,7 +418,7 @@ void KJobTest::slotResult(KJob *job)
 
     // Ensure the job has already emitted finished() if we are tracking from
     // setupErrorResultFinished
-    if(m_jobFinishCount.contains(job)) {
+    if (m_jobFinishCount.contains(job)) {
         QVERIFY(m_jobFinishCount.value(job) == 1);
         QVERIFY(m_jobFinishCount.remove(job) == 1 /* num items removed */);
     }
